@@ -40,8 +40,8 @@ class GeoToad
     $VERSION = versionID.dup
   end
     
-  $SLEEP=1
-  $SLOWMODE=350
+  $SLEEP=0
+  $SLOWMODE=1000000
     
   def initialize
     output        = Output.new
@@ -116,7 +116,7 @@ class GeoToad
     puts " -d/-D [0.0-5.0]        difficulty minimum/maximum"
     puts " -t/-T [0.0-5.0]        terrain minimum/maximum"
     puts " -f/-F [0.0-5.0]        fun factor minimum/maximum"
-    puts " -y    [1-500]          distance maximum in miles (10)"
+    puts " -y    [1-500]          distance maximum in km (10)"
     puts " -k    [keyword]        title keyword search. Use | to delimit multiple"
     puts " -K    [keyword]        desc keyword search (slow). Use | again..."
     puts " -i/-I [username]       include/exclude caches owned by this person"
@@ -174,7 +174,7 @@ class GeoToad
     if (($VERSION =~ /^(\d\.\d+\.\d+)$/) && (version.data =~ /version=(\d\.\d+[\.\d]+)/))
       latestVersion = $1;
       releaseNotes = $2;
-            
+           
       if (latestVersion != $VERSION)
         puts "------------------------------------------------------------------------"
         puts "* NOTE: GeoToad #{latestVersion} is now available!"
@@ -208,10 +208,10 @@ class GeoToad
       # only valid for zip or coordinate searches
             
       if @queryType == "zipcode" || @queryType == "coord"
-        puts "(constraining to #{@distanceMax} miles)"
-        @queryTitle = @queryTitle + " (#{@distanceMax}mi. radius)"
+        puts "(constraining to #{@distanceMax} km)"
+        @queryTitle = @queryTitle + " (#{@distanceMax}km. radius)"
         @defaultOutputFile = @defaultOutputFile + "-y" + @distanceMax.to_s
-        search.distance(@distanceMax.to_i)
+        search.distance(@distanceMax.to_f / 1.609344)
       else
         puts
       end
@@ -439,6 +439,8 @@ class GeoToad
     progress = ProgressBar.new(0, @filtered.totalWaypoints, "Fetching details")
     @detail = CacheDetails.new(wpFiltered)
     @detail.cookie = get_login_cookie()
+    # pass the format type
+    @detail.formatType = @formatType
     token = 0
     downloads = 0
       
@@ -629,7 +631,7 @@ puts "- Please include verbose output (-v) without passwords in the bug report."
 cli = GeoToad.new
 
 while(1)
-  cli.versionCheck
+#  cli.versionCheck
   options = cli.getoptions    
   count = cli.downloadGeocacheList
   if count < 1
