@@ -3,7 +3,7 @@ require 'lib/bishop'
 require 'time'
 
 class CacheDetails
-  attr_writer :useShadow, :cookie
+  attr_writer :useShadow, :cookie, :formatType
     
   include Common
   include Display
@@ -16,6 +16,7 @@ class CacheDetails
   def initialize(data)
     @waypointHash = data
     @useShadow=1
+    @formatType=""
         
     # we don't need to do this every cache! very inefficient.
     dataFile="fun_scores.dat"
@@ -162,10 +163,10 @@ class CacheDetails
         if (! wid)
           debug "Invalid cache, title is: #{$1}"
         elsif (! @waypointHash[wid]['name'])
-          @waypointHash[wid]['name'] = cleanHTML($1)
+          @waypointHash[wid]['name'] = $1
           debug "name was not set, now set to #{$1}"
         else
-          debug "Would set name to #{cleanHTML($1)}, but it is already #{@waypointHash[wid]['name']}"          
+          debug "Would set name to #{$1}, but it is already #{@waypointHash[wid]['name']}"          
         end
       end
 
@@ -357,13 +358,25 @@ class CacheDetails
       if data =~ /id=\"ShortDescription\"\>(.*?)\<\/span\>\s\s\s\s/m
         shortdesc = $1
         debug "found short desc: [#{shortdesc}]"
-        @waypointHash[wid]['shortdesc'] = cleanHTML(shortdesc)
+        @waypointHash[wid]['shortdesc'] = convertHTML(shortdesc)
+      else
+        @waypointHash[wid]['shortdesc'] = ""
       end
             
-      if data =~ /id=\"LongDescription\"\>(.*?)<\/span\>\s\s\s\s/m
+      # fixed the problem with nested spans by manipulation of the regexp
+      if data =~ /\<span id=\"LongDescription\"\>(.*?)\<strong\>Additional Hints&nbsp;/m
         longdesc = $1
         debug "got long desc [#{longdesc}]"
-        @waypointHash[wid]['longdesc'] = cleanHTML(longdesc)
+
+        # Modified HTML cleaning, but only when format != standard GPX
+        if @formatType == "gpx_pa" #gpx_pa is a modded template for Pathaway, which cannot read HTML
+          @waypointHash[wid]['longdesc'] = convertHTML(longdesc)
+        else
+          @waypointHash[wid]['longdesc'] = longdesc
+        end
+        
+      else
+        @waypointHash[wid]['longdesc'] = ""
       end
             
       @waypointHash[wid]['details'] = @waypointHash[wid]['shortdesc'] + " ... " + @waypointHash[wid]['longdesc']
@@ -379,6 +392,62 @@ class CacheDetails
     end
         
   end  # end function
+
+  # Tries to convert HTML to ASCII
+  def convertHTML(text)        
+    # rip some tags out.
+    text.gsub!(/\<\/li\>/i, '')
+    text.gsub!(/\<\/p\>/i, '')
+    text.gsub!(/<\/*i\>/i, '')
+    text.gsub!(/<\/*body\>/im, '')
+    text.gsub!(/<\/*option.*?\>/im, '')
+    text.gsub!(/<\/*select.*?\>/im, '')
+    text.gsub!(/<\/*span.*?\>/im, '')
+    text.gsub!(/<\/*font.*?\>/im, '')
+    text.gsub!(/<\/*ul\>/i, '')
+    text.gsub!(/style=\".*?\"/i, '')
+    text.gsub!(/class=\".*?\"/i, '')
+        
+    debug "post-html-tags-removed: #{text}"
+        
+    # substitute
+    text.gsub!(/<a .*\>(.*)\<a\>/i, "[ln]\1[/ln]")
+    text.gsub!(/\<p\>/i, "\n")
+    text.gsub!(/\<li\>/i, "\n (o) ")
+    text.gsub!(/<\/*b>/i, '')
+    text.gsub!(/\<img.*?\>/im, '[img]')
+    text.gsub!(/\<.*?\>/m, ' ')
+    text.gsub!(/\&quot\;/, '*')
+    text.gsub!(/\"/, '*')
+    debug "pre-combine-process: #{text}"
+        
+    # combine all the tags we nuked. These regexps
+    # could probably be cleaned up pretty well.
+    text.gsub!(/ +/, ' ')
+    
+    debug "post-combine-process: #{text}"
+    text.gsub!(/\&nbsp\;/, " ")			    # unescapeHTML seems to ignore.
+    text.gsub!(/\'+/, "\'")			        # multiple apostrophes
+    # deal with newline clusters
+    text.gsub!(/\x0D\x0A/m, "\n")
+    text.gsub!(/(\x0D\x0A){2,}/m, "\n\n")
+    text.gsub!(/\x0A/m, "\n")
+    text.gsub!(/\x0A{2,}/m, "\n\n")
+        
+    # kill the last space, which makes the CSV output nicer.
+    text.gsub!(/ $/, '')
+
+    # save some tags from unescapeHTML
+    # text.gsub!(/\&amp\;/, '-_-_amp_-_-')
+        
+    # convert things into plain text.
+    # text = CGI.unescapeHTML(text)
+
+    # restore saved tags
+    # text.gsub!(/-_-_([a-z]*)_-_-/, "&\1;")
+
+    return text
+  end
     
   # cleans up HTML and makes it text-worthy.
   def cleanHTML(text)
