@@ -259,6 +259,21 @@ class Output
     debug "Replaced text: #{text}"
     return text
   end
+
+  # convert html-special-chars inside str to utf8 and return a copy
+  def html2utf8(str2)
+    str = str2.dup
+    str.gsub!(/\&\#173\;/, "\xC2\xB2")	
+    str.gsub!(/\&\#228\;/, "\xC3\xA4")	
+    str.gsub!(/\&\#246\;/, "\xC3\xB6")	
+    str.gsub!(/\&\#252\;/, "\xC3\xBC")
+    str.gsub!(/\&\#220\;/, "\xC3\x9C")	
+    str.gsub!(/\&\#196\;/, "\xC3\x84")	
+    str.gsub!(/\&\#214\;/, "\xC3\x96")
+    str.gsub!(/\&\#223\;/, "\xC3\x9F")
+    
+    return str
+  end
     
   def makeXML(str)
     if not str or str.length == 0:
@@ -266,6 +281,11 @@ class Output
     end
     
     # Mangle our scraped HTML enough to pass most XML parsers.
+
+	# replace already replaced tags with utf-8
+	if @outputType == "gpx_pa" || @outputType == "gpx" 
+      str = html2utf8(str)
+    end
     
     text = CGI.escapeHTML(str)
     if text != str
@@ -275,27 +295,42 @@ class Output
     # CGI.escapeHTML will try to re-escape previously escaped entities.
     # For instance, &amp; would become &amp;amp;. We do have to make sure
     # not to fix R&R; though, though &Xi; needs to be fixed.
-    if text =~ /&amp;([\#\w][\w]+;)/   
-      debug "Pre-ampersand: [#{text}] #{text.length}"
-      text.gsub!(/&amp;([\#\w][\w]+;)/, "&#{$1}")
-      debug "Post-ampersand: #{text}"
-    end
+    #if text =~ /&amp;([\#\w][\w]+;)/   
+    #  debug "Pre-ampersand: [#{text}] #{text.length}"
+    #  text.gsub!(/&amp;([\#\w][\w]+;)/, "&#{$1}")
+    #  debug "Post-ampersand: #{text}"
+    #end
 
-    scan_text = text.dup
-    # using scan() here to get around difficulties with \1
-    scan_text.scan(/([\x80-\xFF]+)/) {|highchar|
-      begin
+    # Convert UTF8 to HTML codes when not using GPX output types
+    if @outputType != "gpx_pa" && @outputType != "gpx"
+      scan_text = text.dup
+      # using scan() here to get around difficulties with \1
+      scan_text.scan(/([\x80-\xFF]+)/) {|highchar|
+        begin
         ascii = highchar[0].unpack("U").to_s
         text.gsub!(/#{highchar}/, ("&#" + ascii  + ";"))
-      rescue ArgumentError
+        rescue ArgumentError
         # UTF-8 conversion failed. Lets use a ? instead.
         debug "Malformed UTF-8 char [#{highchar}] in #{scan_text}, using ? instead"
         text.gsub!(/#{highchar}/,'?')
-      end
-    }
+        end
+      }
+    end
     
     # Fix apostrophes so that they show up as expected. Fixes issue 26.
     text.gsub!('&#8217;', "'")
+
+    # deal with newline clusters
+    text.gsub!(/\x0D\x0A/m, "\n")
+    text.gsub!(/(\x0D\x0A){2,}/m, "\n\n")
+    text.gsub!(/\x0A/m, "\n")
+    text.gsub!(/\x0A{2,}/m, "\n\n")
+    
+    # for pathaway we have to limit the maximum amount of chars to <~ 12000
+    paMAXSIZE = 8060
+    if @outputType == "gpx_pa" and text.length() > paMAXSIZE
+       text = text[0..paMAXSIZE-1] + " ... OUT OF SPACE ... "
+    end    
         
     if text != str
       debug "made XML: %s" % text
@@ -328,7 +363,7 @@ class Output
       wpList[wid] = @wpHash[wid]['name'].dup
             
       if @waypointLength > 1
-        sname = shortName(@wpHash[wid]['name'])
+        sname = shortName(html2utf8(@wpHash[wid]['name']))
                 
         # This loop checks for any other caches with the same generated waypoint id
         # If a conflict is found, it looks for the unique characters in them, and
@@ -504,12 +539,12 @@ class Output
           debug "Looking for comment #{x}"                    
           if @wpHash[@currentWid]["comment#{x}Type"]
             rawcomment =
-              "    <groundspeak:log id=\"<%wpEntity.comment#{x}ID%>\">\r\n" +
-              "      <groundspeak:date><%wpEntity.comment#{x}Date%></groundspeak:date>\r\n" +
-              "      <groundspeak:type><%wpEntity.comment#{x}Type%></groundspeak:type>\r\n" +
-              "      <groundspeak:finder id=\"1\"><%wpEntity.comment#{x}Name%></groundspeak:finder>\r\n" +
-              "      <groundspeak:text encoded=\"False\"><%wpEntity.comment#{x}Comment%></groundspeak:text>\r\n" +
-              "    </groundspeak:log>\r\n"                        
+              "    <groundspeak:log id=\"<%wpEntity.comment#{x}ID%>\">\n" +
+              "      <groundspeak:date><%wpEntity.comment#{x}Date%></groundspeak:date>\n" +
+              "      <groundspeak:type><%wpEntity.comment#{x}Type%></groundspeak:type>\n" +
+              "      <groundspeak:finder id=\"1\"><%wpEntity.comment#{x}Name%></groundspeak:finder>\n" +
+              "      <groundspeak:text encoded=\"False\"><%wpEntity.comment#{x}Comment%></groundspeak:text>\n" +
+              "    </groundspeak:log>\n"                        
             @outVars['gpxlogs'] = @outVars['gpxlogs'] + replaceVariables(rawcomment)
           end
         }
